@@ -11,6 +11,7 @@ import tkinter as tk
 global exec_vars
 exec_vars = {}
 
+
 class DCO:
 
     def __init__(self, str):
@@ -22,6 +23,7 @@ class DCO:
     def clear(self):
         self.output = ""
 
+
 """
 Structure Guide
 
@@ -820,8 +822,9 @@ class Interpreter:
         exec_vars = {}
 
     def reset_graph(self, ask=True):
-        if(ask):
-            confirm = input("Are you sure you want to reset the graph? This will delete all nodes and variables. (y/n) ")
+        if (ask):
+            confirm = input(
+                "Are you sure you want to reset the graph? This will delete all nodes and variables. (y/n) ")
             if "y" in confirm:
                 self.graph = Graph()
                 self.reset_runtime()
@@ -840,14 +843,17 @@ class Interpreter:
             return
         self.graph.save_graph(command[1])
 
+
 interpreter = Interpreter()
 
+
 def new_name():
     letters_and_digits = string.ascii_letters + string.digits
     result_str = ''.join((random.choice(letters_and_digits) for i in range(5)))
     return result_str
 
-def create_app(test_config=None):
+
+def dump_app(test_config=None):
     # create and configure the app
     app = Flask(__name__, instance_relative_config=True)
     app.config.from_mapping(
@@ -1017,7 +1023,7 @@ def create_app(test_config=None):
         first = data['first'].strip()
         second = data['second'].strip()
 
-        if(first == second):
+        if (first == second):
             return "false"
 
         interpreter.link(['link', first, second])
@@ -1076,11 +1082,12 @@ def create_app(test_config=None):
     def get_dynamic_cell_output():
         if interpreter.graph.executing:
             return interpreter.std_capture.getvalue()
-        return "<!--SATYRN_DONE_EXECUTING-->" + interpreter.std_capture.getvalue() + ("<execution complete>" if len(interpreter.std_capture.getvalue()) > 0 else "")
+        return "<!--SATYRN_DONE_EXECUTING-->" + interpreter.std_capture.getvalue() + (
+            "<execution complete>" if len(interpreter.std_capture.getvalue()) > 0 else "")
 
     @app.route("/load_graph/", methods=["POST"])
     def load_graph():
-        if(request.get_json()['load_from_file']):
+        if (request.get_json()['load_from_file']):
             interpreter.reset_graph(False)
             raw = request.get_json()['file_contents']
             content = raw.split("\n")
@@ -1150,4 +1157,4 @@ def create_app(test_config=None):
 
         return "true"
 
-    return app
\ No newline at end of file
+    return app
